Core restish Modules — Restish v0.5 documentation

### Navigation

- index
- modules |
- previous |
- Restish v0.5 documentation »

Overview

# Core restish Modules

- `restish.app` - WSGI application code
- `restish.resource` - general purpose HTTP resource
- `restish.http` - HTTP request and response classes, and common response factories
- `restish.url` - comprehensive URL creation and parsing
- `restish.page` - HTML page resource
- `restish.templating` - support for simple templating
- `restish.guard` - protect your resources and methods
- `restish.error` - package-wide exception classes

### Navigation

- index
- modules |
- previous |
- Restish v0.5 documentation »